@@ -16,12 +16,14 @@ async def _get_client(ls: int):
     TonlibClient.enable_unaudited_binaries()
     client = TonlibClient(ls_index=ls)
     await client.init_tonlib()
+    # await client.tonlib_wrapper.cancel_futures()
+    # client.loop
     # await client.set_verbosity_level(5)
     return client
 
 
 def get_client(ls: int = 0):
-    client = asyncio.get_event_loop().run_until_complete(_get_client(ls))
+    client = asyncio.run(_get_client(ls))
     return client
 
 
@@ -53,7 +55,7 @@ def get_items(client: list[TonlibClient] or TonlibClient, addresses: list, filen
             tasks.append(get_item(client[d % len(client)], addr, nft_items, items))
             # print(d % len(client))
             d += 1
-        asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks))
+        asyncio.run(asyncio.gather(*tasks))
         print('DONE')
     if len(nft_items) < len(addresses):
         raise Exception('SCANNED NOT ALL ITEMS')
